@@ -137,22 +137,13 @@ def set_module_name(
     :param conf:                the config of the logger
     :return:                    the config with module name
     """
-    conf["logging"]["formatters"]["fluent_console"]["format"][
-        "module_name"
-    ] = module_name
     conf["logging"]["formatters"]["fluent_debug"]["format"]["module_name"] = module_name
-    conf["logging"]["formatters"]["fluent_console"]["format"][
-        "git_repo_name"
-    ] = git_repo_name
-    conf["logging"]["formatters"]["fluent_debug"]["format"][
-        "git_repo_name"
-    ] = git_repo_name
-    conf["logging"]["formatters"]["fluent_console"]["format"][
-        "docker_image_name"
-    ] = docker_image_name
-    conf["logging"]["formatters"]["fluent_debug"]["format"][
-        "docker_image_name"
-    ] = docker_image_name
+    conf["logging"]["formatters"]["fluent_debug"]["format"]["git_repo_name"] = git_repo_name
+    conf["logging"]["formatters"]["fluent_debug"]["format"]["docker_image_name"] = docker_image_name
+
+    conf["logging"]["formatters"]["fluent_console"]["format"]["module_name"] = module_name
+    conf["logging"]["formatters"]["fluent_console"]["format"]["git_repo_name"] = git_repo_name
+    conf["logging"]["formatters"]["fluent_console"]["format"]["docker_image_name"] = docker_image_name
 
     return conf
 
